Installation
============

To install ``pycvcam``, you can use the following command:

.. code-block:: bash

    pip install pycvcam

Or install it directly from the GitHub repository using:

.. code-block:: bash

    pip install git+https://github.com/Artezaru/pycvcam.git

Requiements
------------

The following dependencies are required to use ``pycvcam``:

- **NumPy**: (https://numpy.org/) A fundamental package for scientific computing.
- **SciPy**: (https://scipy.org/) A library used for scientific and technical computing.
- **OpenCV**: (https://opencv.org/) A library for computer vision and image processing.
- **Py3DFrame**: (https://github.com/Artezaru/py3dframe) A library for working with 3D data frames.
- **PyZernike**: (https://github.com/Artezaru/pyzernike) A library for working with Zernike polynomials.
